@@ -4,7 +4,7 @@
  *  Copyright 2009-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
- * 
+ *
  * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -26,7 +26,7 @@
  *
  */
 extern gchar *current_directory;
- 
+
 /*
  *
  */
@@ -36,5 +36,21 @@ gboolean is_separator(gchar ch);
 
 gchar *fix_separators(gchar *source);
 
+// get the filename from a full path+filename
+gchar *get_filename_from_full_path(gchar *src);
+
+// Convert an absolute file path to a relative file path
+gboolean abs_path_to_relative_path(const gchar *absPath, gchar **relativePath, const gchar *basePath, GError **err);
+
+// Convert a relative file path to an absolute file path
+gboolean relative_path_to_abs_path(gchar *relativePath, gchar **absPath, const gchar *basePath, GError **err);
+
+gchar *get_file_extension(gchar *filename);
+
+int get_number_of_files_in_folder(gchar *folder_name);
+
+gboolean is_string_folder(gchar *instring);
+
+gchar *clean_folder(gchar *folder_name);
 
 #endif /*__HEADER_FILE_UTILS_*/
