@@ -4,7 +4,7 @@
  *  Copyright 2009-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
- * 
+ *
  * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -25,18 +25,12 @@
 /**
  *
  */
-extern GdkPixbuf *header_file_pixbuf;
-extern GdkPixbuf *cpp_file_pixbuf;
-extern GdkPixbuf *txt_file_pixbuf;
-extern GdkPixbuf *lua_file_pixbuf;
-extern GdkPixbuf *java_file_pixbuf;
-
 extern GdkPixbuf *directory_closed_pixbuf;
 extern GdkPixbuf *directory_open_pixbuf;
 
 extern GdkPixbuf *program_icon_pixbuf;
 
-gboolean load_graphics(GError **err);
+gboolean load_graphics(GtkWidget *widget, GError **err);
 void unload_graphics();
 
 extern GdkCursor *standard_cursor;
