@@ -4,7 +4,7 @@
  *  Copyright 2006 Roy Wood, 2009-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
- * 
+ *
  * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -21,7 +21,7 @@
  */
 #ifndef __HEADER_GUI_
 #define __HEADER_GUI_
-	
+
 /**
  * Variables
  */
@@ -33,6 +33,7 @@ extern ClickedNode clicked_node;
 
 extern GtkTreeViewColumn *column1;
 
+extern ClickedNode clicked_node;
 
 // Initialize the GUI
 gboolean setup_gui(GError **err);
@@ -50,11 +51,6 @@ gboolean tree_row_is_expanded(GtkTreePath *path);
 
 // Expand a row
 void expand_tree_row(GtkTreePath *path, gboolean expandChildren);
-void collapse_tree_row(GtkTreePath *path);
-
-void get_dimensions(gint *left, gint *top, gint *width, gint *height);
-
-void update_project_is_dirty(gboolean dirty);
 
 gboolean dialog_response_is_exit(gint test);
 
