@@ -4,7 +4,7 @@
  *  Copyright 2006 Roy Wood, 2009-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
- * 
+ *
  * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -28,20 +28,12 @@ void row_expand_or_collapse_cb(GtkTreeView *treeview, GtkTreeIter *arg1, GtkTree
 
 void quit_menu_cb();
 void about_menu_cb();
-void saveproject_menu_cb();
-void saveproject_as_menu_cb();
-void openproject_menu_cb();
 void creategroup_menu_cb();
 
 void popup_open_file_cb();
 
-void expand_all_items_cb();
-void collapse_all_items_cb();
-
-void sort_ascending_cb();
-void sort_descending_cb();
-
-void edit_options_cb();
+void edit_properties_cb();
 
+void refresh_folder_cb();
 
 #endif /*__HEADER_GUI_CALLBACKS_*/
